@@ -1,20 +1,19 @@
-(unit) @local.scope
+(sub_unit) @local.scope
 
 (function_declaration) @local.scope
+(compound_expression) @local.scope
 
 (global_binding
   (identifier) @local.definition)
-(constant_binding 
+(constant_binding
   (identifier) @local.definition)
-(type_bindings
+(type_binding
   (identifier) @local.definition)
 
 (function_declaration
-  (prototype
-    (parameter_list
-      (parameters
-        (parameter
-          (name) @local.definition)))))
+  (identifier) @local.definition)
+(function_declaration
+  (parameter (name) @local.definition))
 
 (identifier) @local.reference
 
